
#ifndef __MSSENCMSG_H
#define __MSSENCMSG_H 1

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

/**
 * # DEFINE #
 * 曜日(mssCal.cのcal_datefmt関数で利用
 */
#define MssEMdow {"日","月","火","水","木","金","土"}

#endif /* _MSSENCMSG_H */

